Stack

Struct Stack 

pub struct Stack<T> { /* private fields */ }
Allocate memory but never free it until the entire Stack is dropped. Items popped from the stack are marked as Empty so the memory is reused.

Implementations

Source

impl<T> Stack<T>

pub const fn empty() -> Self

Create an empty stack

pub fn next_index(&self) -> usize

Get the next index that will be written to

pub fn with_capacity(cap: usize) -> Self

Create a stack with an initial capacity. This will fill the stack with empty entries

pub fn push(&mut self, value: T)

Push a value onto the stack

pub fn pop(&mut self) -> Option<T>

Pop a value off the stack

pub fn get(&self, index: usize) -> Option<&T>

pub fn swap(&mut self, index: usize, new_value: T) -> T

Swap out a value in the stack at a given location.

Panics

Panics if the index contains an empty slot

pub fn iter(&self) -> impl DoubleEndedIterator<Item = &T> + '_

Create an iterator over the values on the stack

pub fn iter_mut(&mut self) -> impl DoubleEndedIterator<Item = &mut T> + '_

Create an iterator over the values on the stack

pub fn drain( &mut self, ) -> StackDrain<T, impl DoubleEndedIterator<Item = T> + '_>

A draining iterator over the values on the stack.

let mut stack = Stack::empty();
stack.push(1);
stack.push(2);

assert_eq!(stack.drain().next(), Some(2));
assert!(stack.is_empty());
pub fn clear(&mut self)

Clear the values from the stack

pub fn is_empty(&self) -> bool

The stack will contains allocated memory even if is_empty returns true.k

pub fn len(&self) -> usize

pub fn reserve(&mut self, len: usize)

pub fn drain_into(&mut self, local: &mut Stack<T>)

Drain all the values into another stack. Prefer Self::drain_copy_into if T is Copy. It might be marginally faster.

Source

impl<T: PartialEq> Stack<T>

pub fn contains(&self, value: &T) -> bool

Check if the stack contains a given value

Source

impl<T: Copy> Stack<T>

pub fn drain_copy_into(&mut self, local: &mut Stack<T>)

Drain the values into another stack. This function can be marginally faster than Self::drain_into but depends on T being Copy.