InsertTransaction

Struct InsertTransaction 

pub struct InsertTransaction<'a, 'tree, T> { /* private fields */ }

Implementations

Source

impl<'a, 'tree, T> InsertTransaction<'a, 'tree, T>

pub fn new(tree: &'a mut TreeView<'tree, T>, source: &'a [u16]) -> Self

pub fn node_id(&self) -> Key

pub fn commit_child(self, value: T) -> Option<Key>

Insert a child under a given parent. This will return None if the parent does not exist

pub fn commit_at(self, value: T) -> Option<Key>

Insert a node at a given path. This will force all the values after the new node (along with all the children of the values) to have their paths updated.