Buffer

Struct Buffer 

pub struct Buffer<T> { /* private fields */ }
A buffer of copy values with a max size of u32::MAX. Make sure to interreact with the buffer through a session when writing and reading from the buffer:

let mut buffer = Buffer::empty();
let mut session = buffer.new_session();
let key = session.next_slice();

session.extend([1, 2, 3]);

assert_eq!(buffer.get(key), &[1, 2, 3]);

and use the SliceIndex to access the buffer.

Implementations

Source

impl<T: Copy> Buffer<T>

pub fn empty() -> Self

Create an empty buffer.

pub fn new_session(&mut self) -> Session<'_, T>

Create a new session that can be converted into a session key, with access to the underlying storage written to by the session.

pub fn get(&self, index: SliceIndex) -> &[T]

pub fn get_mut(&mut self, index: SliceIndex) -> &mut [T]

pub fn tail_drain(&mut self, size: u32)

Drain values from the end of the buffer, regardless of which key it belongs to.

This will update the last key in the buffer

Panics

Panics if there are no keys in the buffer

pub fn clear(&mut self)

Clear the entire buffer